A collection of asymmetrical kernels belong to lifetime distributions for kernel density estimation is presented. i.e. plot.BS, plot.Erlang,
plot.Gamma, plot.LN and for plotting all densities at same time dencomb. Estimated values can also observed by using
BS, Gamma, Erlang and LN. For calculating mean squared error by using different kernels functions are mseBS, mseEr,
mseGamma and mseLN.
Kernel Density Estimation using Lifetime Distributions
Jin, X.; Kawczak, J. 2003. Birnbaum-Saunders & Lognormal kernel estimators for modeling durations in high frequency financial data. Annals of Economics and Finance 4, 103<U+2013>124.
Salha, R. B.; Ahmed, E. S.; Alhoubi, I. M. 2014. Hazard rate function estimation ksing Erlang Kernel. Pure Mathematical Sciences 3 (4), 141<U+2013>152.
Chen, S. X. 2000. Probability density function estimation using Gamma kernels. Annals of the Institute of Statistical Mathematics 52 (3), 471-480.
Useful links: